# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_storage import XStorage as XStorage_8e460a32

class BaseStorage(XPropertySet_bc180bfa, XStorage_8e460a32):
    """
    Service Class

    This is a service that allows to get access to a storage hierarchy.

    See Also:
        `API BaseStorage <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1embed_1_1BaseStorage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.BaseStorage'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def OpenMode(self) -> int:
        """
        allows to get the mode the storage is opened in.
        
        Can be a combination of values from ElementModes.
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        allows to retrieve URL the storage is based on.
        """
        ...



__all__ = ['BaseStorage']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from ..script.x_event_attacher_manager import XEventAttacherManager as XEventAttacherManager_49f80fde

class FormComponents(XContainer_d6fb0cc6, XEnumerationAccess_4bac0ffc, XIndexContainer_1c040ebe, XNameContainer_cb90e47, XEventAttacherManager_49f80fde):
    """
    Service Class

    specifies the capabilities of a collection of FormComponents.
    
    The collection must provide the possibility of adding and removing components by name and by index. The name of a component is not necessarily unique, so the collection must be able to handle duplicate entry names.

    See Also:
        `API FormComponents <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1FormComponents.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.FormComponents'
    __ooo_type_name__: str = 'service'



__all__ = ['FormComponents']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from enum import Enum


class DashStyle(Enum):
    """
    Enum Class

    

    See Also:
        `API DashStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a89f0dc2e221d6f608088093da27764d1>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.DashStyle'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.drawing.DashStyle'

    RECT = 'RECT'
    """
    the dash is a rectangle
    """
    RECTRELATIVE = 'RECTRELATIVE'
    """
    the dash is a rectangle, with the size of the dash given in relation to the length of the line
    """
    ROUND = 'ROUND'
    """
    the dash is a point
    
    the lines join with an arc
    
    the line will get a half circle as additional cap
    """
    ROUNDRELATIVE = 'ROUNDRELATIVE'
    """
    the dash is a point, with the size of the dash given in relation to the length of the line
    """

__all__ = ['DashStyle']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_remote_content_provider_acceptor import XRemoteContentProviderAcceptor as XRemoteContentProviderAcceptor_af1b125d

class XRemoteContentProviderConnectionControl(XInterface_8f010a43):
    """
    A simple mechanism to find out if the connection between a remote content provider distributor and acceptor gets lost.
    
    This interface should be supported by the DoneListener parameter of XRemoteContentProviderAcceptor.addRemoteContentProvider().

    See Also:
        `API XRemoteContentProviderConnectionControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderConnectionControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XRemoteContentProviderConnectionControl'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XRemoteContentProviderConnectionControl'

    @abstractmethod
    def enableConnectionControl(self, Acceptor: 'XRemoteContentProviderAcceptor_af1b125d', Token: 'XInterface_8f010a43') -> None:
        """
        Enable connection control, using as a token some object implemented on the remote content provider acceptor's side.
        
        The implementation of this interface must hold a reference to the supplied token. If the connection gets lost, the reference count of the token will drop, which the remote content provider acceptor can observe.
        """
        ...

__all__ = ['XRemoteContentProviderConnectionControl']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from .xnss_initializer import XNSSInitializer as XNSSInitializer_27f70ef8

class NSSInitializer(XNSSInitializer_27f70ef8):
    """
    Service Class

    This service has a particular lifecycle.
    
    If you create an instance, the NSS backend is not initialized, until some of the crypto functions are called. As a result you can effectively change the user setting to the NSS path until NSS is really used.
    
    After the first usage you have to restart LibreOffice to activate a new NSS path.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API NSSInitializer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1NSSInitializer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.NSSInitializer'
    __ooo_type_name__: str = 'service'



__all__ = ['NSSInitializer']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from enum import Enum


class TextureKind2(Enum):
    """
    Enum Class

    

    See Also:
        `API TextureKind2 <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.TextureKind2'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.drawing.TextureKind2'

    COLOR = 'COLOR'
    """
    With this mode the lighting is ignored and only the texture color information is used.
    
    With this mode, the lighting is ignored and only the texture color information is used.
    """
    INTENSITY = 'INTENSITY'
    """
    With TextureKind INTENSITY, each texture pixel is used as an intensity value.
    """
    LUMINANCE = 'LUMINANCE'
    """
    With TextureKind LUMINANCE, the texture and the lighting information is mixed to produce the image, so a lit, textured object is achieved.
    """

__all__ = ['TextureKind2']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.style
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XStyleLoader(XInterface_8f010a43):
    """
    enables the object to import styles from documents.

    See Also:
        `API XStyleLoader <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1style_1_1XStyleLoader.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.XStyleLoader'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.style.XStyleLoader'

    @abstractmethod
    def getStyleLoaderOptions(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        """
        ...
    @abstractmethod
    def loadStylesFromURL(self, URL: str, aOptions: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        loads styles from a document at the given URL.
        
        If OverwriteStyles is TRUE, then all styles will be loaded. Otherwise, only styles which are not already defined in this document are loaded.
        
        The sequence<PropertyValue> has the following, optional items:
        
        As the default, all supported style families are loaded and existing styles are overwritten.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XStyleLoader']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XCloneable(XInterface_8f010a43):
    """
    makes it possible to create a copy of the object which supports this interface.

    See Also:
        `API XCloneable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XCloneable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XCloneable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XCloneable'

    @abstractmethod
    def createClone(self) -> 'XCloneable':
        """
        creates a copy of the object.
        """
        ...

__all__ = ['XCloneable']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.deployment.ui
import typing
from abc import abstractmethod
from ...ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924

class LicenseDialog(XExecutableDialog_450f0fa1):
    """
    Service Class

    The LicenseDialog is used to display a license text.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API LicenseDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1deployment_1_1ui_1_1LicenseDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.deployment.ui'
    __ooo_full_ns__: str = 'com.sun.star.deployment.ui.LicenseDialog'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, xParent: 'XWindow_713b0924', extensionName: str, licenseText: str) -> None:
        """
        Create a GUI using the specific parent window and focus on the given context.
        """
        ...


__all__ = ['LicenseDialog']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom
from abc import abstractmethod
from .x_character_data import XCharacterData as XCharacterData_ec070d26

class XText(XCharacterData_ec070d26):
    """

    See Also:
        `API XText <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XText.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.XText'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.XText'

    @abstractmethod
    def splitText(self, offset: int) -> 'XText':
        """
        Breaks this node into two nodes at the specified offset, keeping both in the tree as siblings.
        
        Throws: DOMException - INDEX_SIZE_ERR: Raised if the specified offset is negative or greater than the number of 16-bit units in data. NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...

__all__ = ['XText']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FieldUnit(metaclass=UnoConstMeta, type_name="com.sun.star.awt.FieldUnit", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.FieldUnit``"""
        pass

    class FieldUnitEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.FieldUnit", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.FieldUnit`` as Enum values"""
        pass

else:
    from ...lo.awt.field_unit import FieldUnit as FieldUnit

    class FieldUnitEnum(IntEnum):
        """
        Enum of Const Class FieldUnit

        specifies attributes for the MetricField map units.
        
        IMPORTANT: These constants have to be disjunct with constants in util/MeasureUnit.
        """
        FUNIT_NONE = FieldUnit.FUNIT_NONE
        FUNIT_MM = FieldUnit.FUNIT_MM
        FUNIT_CM = FieldUnit.FUNIT_CM
        FUNIT_M = FieldUnit.FUNIT_M
        FUNIT_KM = FieldUnit.FUNIT_KM
        FUNIT_TWIP = FieldUnit.FUNIT_TWIP
        FUNIT_POINT = FieldUnit.FUNIT_POINT
        FUNIT_PICA = FieldUnit.FUNIT_PICA
        FUNIT_INCH = FieldUnit.FUNIT_INCH
        FUNIT_FOOT = FieldUnit.FUNIT_FOOT
        FUNIT_MILE = FieldUnit.FUNIT_MILE
        FUNIT_CUSTOM = FieldUnit.FUNIT_CUSTOM
        FUNIT_PERCENT = FieldUnit.FUNIT_PERCENT
        FUNIT_100TH_MM = FieldUnit.FUNIT_100TH_MM

__all__ = ['FieldUnit', 'FieldUnitEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.ui.action_trigger import ActionTrigger as ActionTrigger
from ...dyn.ui.action_trigger_container import ActionTriggerContainer as ActionTriggerContainer
from ...dyn.ui.action_trigger_separator import ActionTriggerSeparator as ActionTriggerSeparator
from ...dyn.ui.action_trigger_separator_type import ActionTriggerSeparatorType as ActionTriggerSeparatorType
from ...dyn.ui.action_trigger_separator_type import ActionTriggerSeparatorTypeEnum as ActionTriggerSeparatorTypeEnum
from ...dyn.ui.address_book_source_dialog import AddressBookSourceDialog as AddressBookSourceDialog
from ...dyn.ui.configurable_ui_element import ConfigurableUIElement as ConfigurableUIElement
from ...dyn.ui.configuration_event import ConfigurationEvent as ConfigurationEvent
from ...dyn.ui.context_change_event_multiplexer import ContextChangeEventMultiplexer as ContextChangeEventMultiplexer
from ...dyn.ui.context_change_event_object import ContextChangeEventObject as ContextChangeEventObject
from ...dyn.ui.context_menu_execute_event import ContextMenuExecuteEvent as ContextMenuExecuteEvent
from ...dyn.ui.context_menu_interceptor_action import ContextMenuInterceptorAction as ContextMenuInterceptorAction
from ...dyn.ui.docking_area import DockingArea as DockingArea
from ...dyn.ui.document_accelerator_configuration import DocumentAcceleratorConfiguration as DocumentAcceleratorConfiguration
from ...dyn.ui.global_accelerator_configuration import GlobalAcceleratorConfiguration as GlobalAcceleratorConfiguration
from ...dyn.ui.image_manager import ImageManager as ImageManager
from ...dyn.ui.image_type import ImageType as ImageType
from ...dyn.ui.image_type import ImageTypeEnum as ImageTypeEnum
from ...dyn.ui.item_descriptor import ItemDescriptor as ItemDescriptor
from ...dyn.ui.item_style import ItemStyle as ItemStyle
from ...dyn.ui.item_style import ItemStyleEnum as ItemStyleEnum
from ...dyn.ui.item_type import ItemType as ItemType
from ...dyn.ui.item_type import ItemTypeEnum as ItemTypeEnum
from ...dyn.ui.layout_size import LayoutSize as LayoutSize
from ...dyn.ui.module_accelerator_configuration import ModuleAcceleratorConfiguration as ModuleAcceleratorConfiguration
from ...dyn.ui.module_ui_category_description import ModuleUICategoryDescription as ModuleUICategoryDescription
from ...dyn.ui.module_ui_command_description import ModuleUICommandDescription as ModuleUICommandDescription
from ...dyn.ui.module_ui_configuration_manager import ModuleUIConfigurationManager as ModuleUIConfigurationManager
from ...dyn.ui.module_ui_configuration_manager_supplier import ModuleUIConfigurationManagerSupplier as ModuleUIConfigurationManagerSupplier
from ...dyn.ui.module_window_state_configuration import ModuleWindowStateConfiguration as ModuleWindowStateConfiguration
from ...dyn.ui.ui_category_description import UICategoryDescription as UICategoryDescription
from ...dyn.ui.ui_configuration_manager import UIConfigurationManager as UIConfigurationManager
from ...dyn.ui.ui_element import UIElement as UIElement
from ...dyn.ui.ui_element_factory import UIElementFactory as UIElementFactory
from ...dyn.ui.ui_element_factory_manager import UIElementFactoryManager as UIElementFactoryManager
from ...dyn.ui.ui_element_settings import UIElementSettings as UIElementSettings
from ...dyn.ui.ui_element_type import UIElementType as UIElementType
from ...dyn.ui.ui_element_type import UIElementTypeEnum as UIElementTypeEnum
from ...dyn.ui.window_content_factory import WindowContentFactory as WindowContentFactory
from ...dyn.ui.window_content_factory_manager import WindowContentFactoryManager as WindowContentFactoryManager
from ...dyn.ui.window_state_configuration import WindowStateConfiguration as WindowStateConfiguration
from ...dyn.ui.x_accelerator_configuration import XAcceleratorConfiguration as XAcceleratorConfiguration
from ...dyn.ui.x_context_change_event_listener import XContextChangeEventListener as XContextChangeEventListener
from ...dyn.ui.x_context_change_event_multiplexer import XContextChangeEventMultiplexer as XContextChangeEventMultiplexer
from ...dyn.ui.x_context_menu_interception import XContextMenuInterception as XContextMenuInterception
from ...dyn.ui.x_context_menu_interceptor import XContextMenuInterceptor as XContextMenuInterceptor
from ...dyn.ui.x_deck import XDeck as XDeck
from ...dyn.ui.x_decks import XDecks as XDecks
from ...dyn.ui.x_docking_area_acceptor import XDockingAreaAcceptor as XDockingAreaAcceptor
from ...dyn.ui.x_image_manager import XImageManager as XImageManager
from ...dyn.ui.x_module_ui_configuration_manager import XModuleUIConfigurationManager as XModuleUIConfigurationManager
from ...dyn.ui.x_module_ui_configuration_manager2 import XModuleUIConfigurationManager2 as XModuleUIConfigurationManager2
from ...dyn.ui.x_module_ui_configuration_manager_supplier import XModuleUIConfigurationManagerSupplier as XModuleUIConfigurationManagerSupplier
from ...dyn.ui.x_panel import XPanel as XPanel
from ...dyn.ui.x_panels import XPanels as XPanels
from ...dyn.ui.x_sidebar import XSidebar as XSidebar
from ...dyn.ui.x_sidebar_panel import XSidebarPanel as XSidebarPanel
from ...dyn.ui.x_sidebar_provider import XSidebarProvider as XSidebarProvider
from ...dyn.ui.x_statusbar_item import XStatusbarItem as XStatusbarItem
from ...dyn.ui.x_tool_panel import XToolPanel as XToolPanel
from ...dyn.ui.xui_configuration import XUIConfiguration as XUIConfiguration
from ...dyn.ui.xui_configuration_listener import XUIConfigurationListener as XUIConfigurationListener
from ...dyn.ui.xui_configuration_manager import XUIConfigurationManager as XUIConfigurationManager
from ...dyn.ui.xui_configuration_manager2 import XUIConfigurationManager2 as XUIConfigurationManager2
from ...dyn.ui.xui_configuration_manager_supplier import XUIConfigurationManagerSupplier as XUIConfigurationManagerSupplier
from ...dyn.ui.xui_configuration_persistence import XUIConfigurationPersistence as XUIConfigurationPersistence
from ...dyn.ui.xui_configuration_storage import XUIConfigurationStorage as XUIConfigurationStorage
from ...dyn.ui.xui_element import XUIElement as XUIElement
from ...dyn.ui.xui_element_factory import XUIElementFactory as XUIElementFactory
from ...dyn.ui.xui_element_factory_manager import XUIElementFactoryManager as XUIElementFactoryManager
from ...dyn.ui.xui_element_factory_registration import XUIElementFactoryRegistration as XUIElementFactoryRegistration
from ...dyn.ui.xui_element_settings import XUIElementSettings as XUIElementSettings
from ...dyn.ui.xui_function_listener import XUIFunctionListener as XUIFunctionListener
from ...dyn.ui.x_update_model import XUpdateModel as XUpdateModel
from ...dyn.ui.the_module_ui_configuration_manager_supplier import theModuleUIConfigurationManagerSupplier as theModuleUIConfigurationManagerSupplier
from ...dyn.ui.the_ui_category_description import theUICategoryDescription as theUICategoryDescription
from ...dyn.ui.the_ui_element_factory_manager import theUIElementFactoryManager as theUIElementFactoryManager
from ...dyn.ui.the_window_content_factory_manager import theWindowContentFactoryManager as theWindowContentFactoryManager
from ...dyn.ui.the_window_state_configuration import theWindowStateConfiguration as theWindowStateConfiguration



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.security.access_control_exception import AccessControlException as AccessControlException
from ...dyn.security.access_controller import AccessController as AccessController
from ...dyn.security.all_permission import AllPermission as AllPermission
from ...dyn.security.cert_alt_name_entry import CertAltNameEntry as CertAltNameEntry
from ...dyn.security.certificate_characters import CertificateCharacters as CertificateCharacters
from ...dyn.security.certificate_characters import CertificateCharactersEnum as CertificateCharactersEnum
from ...dyn.security.certificate_container import CertificateContainer as CertificateContainer
from ...dyn.security.certificate_container_status import CertificateContainerStatus as CertificateContainerStatus
from ...dyn.security.certificate_exception import CertificateException as CertificateException
from ...dyn.security.certificate_kind import CertificateKind as CertificateKind
from ...dyn.security.certificate_validity import CertificateValidity as CertificateValidity
from ...dyn.security.certificate_validity import CertificateValidityEnum as CertificateValidityEnum
from ...dyn.security.cryptography_exception import CryptographyException as CryptographyException
from ...dyn.security.document_digital_signatures import DocumentDigitalSignatures as DocumentDigitalSignatures
from ...dyn.security.document_signature_information import DocumentSignatureInformation as DocumentSignatureInformation
from ...dyn.security.encryption_exception import EncryptionException as EncryptionException
from ...dyn.security.ext_alt_name_type import ExtAltNameType as ExtAltNameType
from ...dyn.security.key_exception import KeyException as KeyException
from ...dyn.security.key_usage import KeyUsage as KeyUsage
from ...dyn.security.key_usage import KeyUsageEnum as KeyUsageEnum
from ...dyn.security.no_password_exception import NoPasswordException as NoPasswordException
from ...dyn.security.policy import Policy as Policy
from ...dyn.security.runtime_permission import RuntimePermission as RuntimePermission
from ...dyn.security.security_infrastructure_exception import SecurityInfrastructureException as SecurityInfrastructureException
from ...dyn.security.signature_exception import SignatureException as SignatureException
from ...dyn.security.x_access_control_context import XAccessControlContext as XAccessControlContext
from ...dyn.security.x_access_controller import XAccessController as XAccessController
from ...dyn.security.x_action import XAction as XAction
from ...dyn.security.x_certificate import XCertificate as XCertificate
from ...dyn.security.x_certificate_container import XCertificateContainer as XCertificateContainer
from ...dyn.security.x_certificate_extension import XCertificateExtension as XCertificateExtension
from ...dyn.security.x_document_digital_signatures import XDocumentDigitalSignatures as XDocumentDigitalSignatures
from ...dyn.security.x_policy import XPolicy as XPolicy
from ...dyn.security.x_san_extension import XSanExtension as XSanExtension



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.deployment.dependency_exception import DependencyException as DependencyException
from ...dyn.deployment.deployment_exception import DeploymentException as DeploymentException
from ...dyn.deployment.extension_manager import ExtensionManager as ExtensionManager
from ...dyn.deployment.extension_removed_exception import ExtensionRemovedException as ExtensionRemovedException
from ...dyn.deployment.install_exception import InstallException as InstallException
from ...dyn.deployment.invalid_removed_parameter_exception import InvalidRemovedParameterException as InvalidRemovedParameterException
from ...dyn.deployment.license_exception import LicenseException as LicenseException
from ...dyn.deployment.package_information_provider import PackageInformationProvider as PackageInformationProvider
from ...dyn.deployment.package_registry_backend import PackageRegistryBackend as PackageRegistryBackend
from ...dyn.deployment.platform_exception import PlatformException as PlatformException
from ...dyn.deployment.prerequisites import Prerequisites as Prerequisites
from ...dyn.deployment.prerequisites import PrerequisitesEnum as PrerequisitesEnum
from ...dyn.deployment.update_information_entry import UpdateInformationEntry as UpdateInformationEntry
from ...dyn.deployment.update_information_provider import UpdateInformationProvider as UpdateInformationProvider
from ...dyn.deployment.version_exception import VersionException as VersionException
from ...dyn.deployment.x_extension_manager import XExtensionManager as XExtensionManager
from ...dyn.deployment.x_package import XPackage as XPackage
from ...dyn.deployment.x_package_information_provider import XPackageInformationProvider as XPackageInformationProvider
from ...dyn.deployment.x_package_manager import XPackageManager as XPackageManager
from ...dyn.deployment.x_package_manager_factory import XPackageManagerFactory as XPackageManagerFactory
from ...dyn.deployment.x_package_registry import XPackageRegistry as XPackageRegistry
from ...dyn.deployment.x_package_type_info import XPackageTypeInfo as XPackageTypeInfo
from ...dyn.deployment.x_update_information_provider import XUpdateInformationProvider as XUpdateInformationProvider
from ...dyn.deployment.the_package_manager_factory import thePackageManagerFactory as thePackageManagerFactory



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.beans.ambiguous import Ambiguous as Ambiguous
from ...dyn.beans.defaulted import Defaulted as Defaulted
from ...dyn.beans.get_direct_property_tolerant_result import GetDirectPropertyTolerantResult as GetDirectPropertyTolerantResult
from ...dyn.beans.get_property_tolerant_result import GetPropertyTolerantResult as GetPropertyTolerantResult
from ...dyn.beans.illegal_type_exception import IllegalTypeException as IllegalTypeException
from ...dyn.beans.introspection import Introspection as Introspection
from ...dyn.beans.introspection_exception import IntrospectionException as IntrospectionException
from ...dyn.beans.method_concept import MethodConcept as MethodConcept
from ...dyn.beans.method_concept import MethodConceptEnum as MethodConceptEnum
from ...dyn.beans.named_value import NamedValue as NamedValue
from ...dyn.beans.not_removeable_exception import NotRemoveableException as NotRemoveableException
from ...dyn.beans.optional import Optional as Optional
from ...dyn.beans.pair import Pair as Pair
from ...dyn.beans.property import Property as Property
from ...dyn.beans.property_attribute import PropertyAttribute as PropertyAttribute
from ...dyn.beans.property_attribute import PropertyAttributeEnum as PropertyAttributeEnum
from ...dyn.beans.property_bag import PropertyBag as PropertyBag
from ...dyn.beans.property_change_event import PropertyChangeEvent as PropertyChangeEvent
from ...dyn.beans.property_concept import PropertyConcept as PropertyConcept
from ...dyn.beans.property_concept import PropertyConceptEnum as PropertyConceptEnum
from ...dyn.beans.property_exist_exception import PropertyExistException as PropertyExistException
from ...dyn.beans.property_set import PropertySet as PropertySet
from ...dyn.beans.property_set_info_change import PropertySetInfoChange as PropertySetInfoChange
from ...dyn.beans.property_set_info_change import PropertySetInfoChangeEnum as PropertySetInfoChangeEnum
from ...dyn.beans.property_set_info_change_event import PropertySetInfoChangeEvent as PropertySetInfoChangeEvent
from ...dyn.beans.property_state import PropertyState as PropertyState
from ...dyn.beans.property_state_change_event import PropertyStateChangeEvent as PropertyStateChangeEvent
from ...dyn.beans.property_value import PropertyValue as PropertyValue
from ...dyn.beans.property_values import PropertyValues as PropertyValues
from ...dyn.beans.property_veto_exception import PropertyVetoException as PropertyVetoException
from ...dyn.beans.set_property_tolerant_failed import SetPropertyTolerantFailed as SetPropertyTolerantFailed
from ...dyn.beans.string_pair import StringPair as StringPair
from ...dyn.beans.tolerant_property_set_result_type import TolerantPropertySetResultType as TolerantPropertySetResultType
from ...dyn.beans.tolerant_property_set_result_type import TolerantPropertySetResultTypeEnum as TolerantPropertySetResultTypeEnum
from ...dyn.beans.unknown_property_exception import UnknownPropertyException as UnknownPropertyException
from ...dyn.beans.x_exact_name import XExactName as XExactName
from ...dyn.beans.x_fast_property_set import XFastPropertySet as XFastPropertySet
from ...dyn.beans.x_hierarchical_property_set import XHierarchicalPropertySet as XHierarchicalPropertySet
from ...dyn.beans.x_hierarchical_property_set_info import XHierarchicalPropertySetInfo as XHierarchicalPropertySetInfo
from ...dyn.beans.x_introspection import XIntrospection as XIntrospection
from ...dyn.beans.x_introspection_access import XIntrospectionAccess as XIntrospectionAccess
from ...dyn.beans.x_material_holder import XMaterialHolder as XMaterialHolder
from ...dyn.beans.x_multi_hierarchical_property_set import XMultiHierarchicalPropertySet as XMultiHierarchicalPropertySet
from ...dyn.beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet
from ...dyn.beans.x_multi_property_states import XMultiPropertyStates as XMultiPropertyStates
from ...dyn.beans.x_properties_change_listener import XPropertiesChangeListener as XPropertiesChangeListener
from ...dyn.beans.x_properties_change_notifier import XPropertiesChangeNotifier as XPropertiesChangeNotifier
from ...dyn.beans.x_property import XProperty as XProperty
from ...dyn.beans.x_property_access import XPropertyAccess as XPropertyAccess
from ...dyn.beans.x_property_bag import XPropertyBag as XPropertyBag
from ...dyn.beans.x_property_change_listener import XPropertyChangeListener as XPropertyChangeListener
from ...dyn.beans.x_property_container import XPropertyContainer as XPropertyContainer
from ...dyn.beans.x_property_set import XPropertySet as XPropertySet
from ...dyn.beans.x_property_set_info import XPropertySetInfo as XPropertySetInfo
from ...dyn.beans.x_property_set_info_change_listener import XPropertySetInfoChangeListener as XPropertySetInfoChangeListener
from ...dyn.beans.x_property_set_info_change_notifier import XPropertySetInfoChangeNotifier as XPropertySetInfoChangeNotifier
from ...dyn.beans.x_property_set_option import XPropertySetOption as XPropertySetOption
from ...dyn.beans.x_property_state import XPropertyState as XPropertyState
from ...dyn.beans.x_property_state_change_listener import XPropertyStateChangeListener as XPropertyStateChangeListener
from ...dyn.beans.x_property_with_state import XPropertyWithState as XPropertyWithState
from ...dyn.beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet
from ...dyn.beans.x_vetoable_change_listener import XVetoableChangeListener as XVetoableChangeListener
from ...dyn.beans.the_introspection import theIntrospection as theIntrospection



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.uno
# Libre Office Version: 7.4
from enum import Enum


class TypeClass(Enum):
    """
    Enum Class

    

    See Also:
        `API TypeClass <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328>`_
    """
    __ooo_ns__: str = 'com.sun.star.uno'
    __ooo_full_ns__: str = 'com.sun.star.uno.TypeClass'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.uno.TypeClass'

    ANY = 'ANY'
    """
    reflecting the any type; anys can carry any UNO value except of any values
    """
    ARRAY = 'ARRAY'
    """
    Deprecated, UNOIDL does not have an array concept.
    """
    BOOLEAN = 'BOOLEAN'
    """
    reflecting the boolean type; true and false
    """
    BYTE = 'BYTE'
    """
    reflecting the 8-bit ordinal type
    """
    CHAR = 'CHAR'
    """
    reflecting the 16-bit unicode character type
    """
    CONSTANT = 'CONSTANT'
    """
    reflecting constants
    """
    CONSTANTS = 'CONSTANTS'
    """
    reflecting constants groups
    """
    DOUBLE = 'DOUBLE'
    """
    reflecting the 64-bit floating point type
    """
    ENUM = 'ENUM'
    """
    reflecting enum types
    """
    EXCEPTION = 'EXCEPTION'
    """
    reflecting exception types
    """
    FLOAT = 'FLOAT'
    """
    reflecting the 32-bit floating point type
    """
    HYPER = 'HYPER'
    """
    reflecting the signed 64-bit ordinal type
    """
    INTERFACE = 'INTERFACE'
    """
    reflecting interface types
    """
    INTERFACE_ATTRIBUTE = 'INTERFACE_ATTRIBUTE'
    """
    reflecting interface attributes
    """
    INTERFACE_METHOD = 'INTERFACE_METHOD'
    """
    reflecting interface methods
    """
    LONG = 'LONG'
    """
    reflecting the signed 32-bit ordinal type
    """
    MODULE = 'MODULE'
    """
    reflecting modules
    """
    PROPERTY = 'PROPERTY'
    """
    reflecting properties
    """
    SEQUENCE = 'SEQUENCE'
    """
    reflecting sequence types
    """
    SERVICE = 'SERVICE'
    """
    reflecting services
    """
    SHORT = 'SHORT'
    """
    reflecting the signed 16-bit ordinal type
    """
    SINGLETON = 'SINGLETON'
    """
    reflecting singletons
    """
    STRING = 'STRING'
    """
    reflecting the string type; strings of unicode characters
    """
    STRUCT = 'STRUCT'
    """
    reflecting compound types
    """
    TYPE = 'TYPE'
    """
    reflecting the meta type
    """
    TYPEDEF = 'TYPEDEF'
    """
    reflecting typedefed types referencing other types
    """
    UNION = 'UNION'
    """
    Deprecated, UNOIDL does not have a union concept.
    """
    UNKNOWN = 'UNKNOWN'
    """
    reflecting the unreflectable type
    """
    UNSIGNED_HYPER = 'UNSIGNED_HYPER'
    """
    reflecting the unsigned 64-bit ordinal type
    """
    UNSIGNED_LONG = 'UNSIGNED_LONG'
    """
    reflecting the unsigned 32-bit type
    """
    UNSIGNED_SHORT = 'UNSIGNED_SHORT'
    """
    reflecting the unsigned 16-bit ordinal type
    """
    VOID = 'VOID'
    """
    reflecting the void type; denotes no type
    """

__all__ = ['TypeClass']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class SendInfo(object):
    """
    Struct Class

    contains information related to a send protocol.
    
    It can contain any string values (server names, user names, passwords, ...).

    See Also:
        `API SendInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1SendInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.SendInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.SendInfo'
    """Literal Constant ``com.sun.star.ucb.SendInfo``"""

    def __init__(self, ProtocolType: typing.Optional[str] = '', Value: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            ProtocolType (str, optional): ProtocolType value.
            Value (str, optional): Value value.
        """
        super().__init__()

        if isinstance(ProtocolType, SendInfo):
            oth: SendInfo = ProtocolType
            self.ProtocolType = oth.ProtocolType
            self.Value = oth.Value
            return

        kargs = {
            "ProtocolType": ProtocolType,
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._protocol_type = kwargs["ProtocolType"]
        self._value = kwargs["Value"]


    @property
    def ProtocolType(self) -> str:
        """
        the protocol to which the info is related (i.e.
        
        \"NNTP\", \"SMTP\", \"VIM\").
        """
        return self._protocol_type
    
    @ProtocolType.setter
    def ProtocolType(self, value: str) -> None:
        self._protocol_type = value

    @property
    def Value(self) -> str:
        """
        the value.
        """
        return self._value
    
    @Value.setter
    def Value(self, value: str) -> None:
        self._value = value


__all__ = ['SendInfo']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XUnoTunnel(XInterface_8f010a43):
    """
    An interface to tunnel UNO.
    
    This means providing access to data or something else, which is not specified by UNO-IDL.
    
    Common usage: Getting a C++ object pointer in the same process, thus to use an implementation directly, most often because of a design flaw.

    See Also:
        `API XUnoTunnel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1lang_1_1XUnoTunnel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.XUnoTunnel'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.lang.XUnoTunnel'

    @abstractmethod
    def getSomething(self, aIdentifier: uno.ByteSequence) -> int:
        """
        Call this method to get something which is not specified in UNO, e.g.
        
        an address to some C++ object.
        """
        ...

__all__ = ['XUnoTunnel']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class PanoseProportion(metaclass=UnoConstMeta, type_name="com.sun.star.rendering.PanoseProportion", name_space="com.sun.star.rendering"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.rendering.PanoseProportion``"""
        pass

    class PanoseProportionEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.rendering.PanoseProportion", name_space="com.sun.star.rendering"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.rendering.PanoseProportion`` as Enum values"""
        pass

else:
    from ...lo.rendering.panose_proportion import PanoseProportion as PanoseProportion

    class PanoseProportionEnum(IntEnum):
        """
        Enum of Const Class PanoseProportion

        """
        ANYTHING = PanoseProportion.ANYTHING
        NO_FIT = PanoseProportion.NO_FIT
        OLD_SKOOL = PanoseProportion.OLD_SKOOL
        MODERN = PanoseProportion.MODERN
        EVEN_WIDTH = PanoseProportion.EVEN_WIDTH
        EXPANDED = PanoseProportion.EXPANDED
        CONDENSED = PanoseProportion.CONDENSED
        VERY_EXPANDED = PanoseProportion.VERY_EXPANDED
        VERY_CONDENSED = PanoseProportion.VERY_CONDENSED
        MONO_SPACED = PanoseProportion.MONO_SPACED

__all__ = ['PanoseProportion', 'PanoseProportionEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..drawing.fill_properties import FillProperties as FillProperties_f1200da8
from ..drawing.line_properties import LineProperties as LineProperties_f13f0da9
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222

class ChartArea(FillProperties_f1200da8, LineProperties_f13f0da9, UserDefinedAttributesSupplier_9fbe1222, XPropertySet_bc180bfa):
    """
    Service Class

    Specifies the area elements of a chart, e.g.
    
    the background area, the diagram wall, and the diagram floor of three-dimensional charts.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ChartArea <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartArea.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartArea'
    __ooo_type_name__: str = 'service'



__all__ = ['ChartArea']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ParagraphVertAlign(metaclass=UnoConstMeta, type_name="com.sun.star.text.ParagraphVertAlign", name_space="com.sun.star.text"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.text.ParagraphVertAlign``"""
        pass

    class ParagraphVertAlignEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.text.ParagraphVertAlign", name_space="com.sun.star.text"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.text.ParagraphVertAlign`` as Enum values"""
        pass

else:
    from ...lo.text.paragraph_vert_align import ParagraphVertAlign as ParagraphVertAlign

    class ParagraphVertAlignEnum(IntEnum):
        """
        Enum of Const Class ParagraphVertAlign

        These enumeration values are used to specify the vertical alignment of paragraphs.
        """
        AUTOMATIC = ParagraphVertAlign.AUTOMATIC
        """
        In automatic mode, horizontal text is aligned to the baseline.
        
        The same applies to text that is rotated 90°. Text that is rotated 270 ° is aligned to the center.
        """
        BASELINE = ParagraphVertAlign.BASELINE
        """
        The text is aligned to the baseline.
        """
        TOP = ParagraphVertAlign.TOP
        """
        The text is aligned to the top.
        """
        CENTER = ParagraphVertAlign.CENTER
        """
        The text is aligned to the center.
        """
        BOTTOM = ParagraphVertAlign.BOTTOM
        """
        The text is aligned to bottom.
        """

__all__ = ['ParagraphVertAlign', 'ParagraphVertAlignEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .data_flavor import DataFlavor as DataFlavor_ffd30deb

class XDataFormatTranslator(XInterface_8f010a43):
    """
    Interface to be implemented by objects used to translate a DataFlavor to a system dependent data transfer type and vice versa.
    
    Different platforms use different types to describe data formats available during data exchange operations like clipboard or drag&drop. Windows for instance uses integer values to describe an available clipboard or drag&drop format, Unix X11 uses so called Atoms etc.

    See Also:
        `API XDataFormatTranslator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1XDataFormatTranslator.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.XDataFormatTranslator'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.XDataFormatTranslator'

    @abstractmethod
    def getDataFlavorFromSystemDataType(self, aSysDataType: object) -> 'DataFlavor_ffd30deb':
        """
        Converts a system dependent data type to a DataFlavor.
        
        If there is no appropriate mapping for a system dependent data type, the returned DataFlavor will be empty.
        """
        ...
    @abstractmethod
    def getSystemDataTypeFromDataFlavor(self, aDataFlavor: 'DataFlavor_ffd30deb') -> object:
        """
        Converts a DataFlavor to system dependent data type.
        
        If the is no system dependent data type for a given DataFlavor the returned any is empty.
        """
        ...

__all__ = ['XDataFormatTranslator']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
import typing
from abc import abstractmethod
from .xole_simple_storage import XOLESimpleStorage as XOLESimpleStorage_f6db0d7c
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_stream import XStream as XStream_678908a4

class OLESimpleStorage(XOLESimpleStorage_f6db0d7c):
    """
    Service Class

    This service provides a simple functionality to allow read/write the storages in OLE storage format.

    See Also:
        `API OLESimpleStorage <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1embed_1_1OLESimpleStorage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.OLESimpleStorage'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createFromInputStream(self, xInputStream: 'XInputStream_98d40ab4', bNoTempCopy: bool) -> None:
        """
        is used to initialize the object on it's creation.
        """
        ...
    @abstractmethod
    def createFromStream(self, xStream: 'XStream_678908a4', bNoTempCopy: bool) -> None:
        """
        is used to initialize the object on it's creation.
        """
        ...


__all__ = ['OLESimpleStorage']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .cell_insert_mode import CellInsertMode as CellInsertMode_d47d0c9b
    from .paste_operation import PasteOperation as PasteOperation_d5de0ccf
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XSheetPastable(XInterface_8f010a43):
    """
    represents a sheet into which contents of the clipboard can be pasted.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XSheetPastable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPastable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetPastable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetPastable'

    @abstractmethod
    def paste(self, aDestination: 'CellAddress_ae5f0b56') -> None:
        """
        pastes the contents of the clipboard at the specified position on the sheet.
        """
        ...
    @abstractmethod
    def pasteCellRange(self, aDestination: 'CellRangeAddress_ec450d43', nOperation: 'PasteOperation_d5de0ccf', nContents: int, bSkipEmpty: bool, bTranspose: bool, bAsLink: bool, nInsert: 'CellInsertMode_d47d0c9b') -> None:
        """
        pastes clipboard data from a cell range into another cell range.
        
        The contents of the clipboard must be from a cell range.
        """
        ...
    @abstractmethod
    def pasteFormat(self, aDestination: 'CellAddress_ae5f0b56', aFormat: str) -> None:
        """
        pastes the contents of the clipboard at the specified position on the sheet, using the specified format.
        """
        ...

__all__ = ['XSheetPastable']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.uno.deployment_exception import DeploymentException as DeploymentException
from ...dyn.uno.exception import Exception as Exception
from ...dyn.uno.naming_service import NamingService as NamingService
from ...dyn.uno.runtime_exception import RuntimeException as RuntimeException
from ...dyn.uno.security_exception import SecurityException as SecurityException
from ...dyn.uno.type_class import TypeClass as TypeClass
from ...dyn.uno.uik import Uik as Uik
from ...dyn.uno.x_adapter import XAdapter as XAdapter
from ...dyn.uno.x_aggregation import XAggregation as XAggregation
from ...dyn.uno.x_component_context import XComponentContext as XComponentContext
from ...dyn.uno.x_current_context import XCurrentContext as XCurrentContext
from ...dyn.uno.x_interface import XInterface as XInterface
from ...dyn.uno.x_naming_service import XNamingService as XNamingService
from ...dyn.uno.x_reference import XReference as XReference
from ...dyn.uno.x_unloading_preference import XUnloadingPreference as XUnloadingPreference
from ...dyn.uno.x_weak import XWeak as XWeak



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_shape import XShape as XShape_8fd00a3d

class XShapes2(ABC):
    """
    Allows insertion of shapes at different positions.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API XShapes2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XShapes2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XShapes2'

    @abstractmethod
    def addBottom(self, xShape: 'XShape_8fd00a3d') -> None:
        """
        Insert a new shape to the bottom of the stack.
        
        **since**
        
            LibreOffice 4.2
        """
        ...
    @abstractmethod
    def addTop(self, xShape: 'XShape_8fd00a3d') -> None:
        """
        Insert a new shape to the top of the stack.
        
        **since**
        
            LibreOffice 4.2
        """
        ...

__all__ = ['XShapes2']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class CellRangeAddress(object):
    """
    Struct Class

    contains a cell range address within a spreadsheet document.

    See Also:
        `API CellRangeAddress <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1CellRangeAddress.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.CellRangeAddress'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.table.CellRangeAddress'
    """Literal Constant ``com.sun.star.table.CellRangeAddress``"""

    def __init__(self, Sheet: typing.Optional[int] = 0, StartColumn: typing.Optional[int] = 0, StartRow: typing.Optional[int] = 0, EndColumn: typing.Optional[int] = 0, EndRow: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Sheet (int, optional): Sheet value.
            StartColumn (int, optional): StartColumn value.
            StartRow (int, optional): StartRow value.
            EndColumn (int, optional): EndColumn value.
            EndRow (int, optional): EndRow value.
        """
        super().__init__()

        if isinstance(Sheet, CellRangeAddress):
            oth: CellRangeAddress = Sheet
            self.Sheet = oth.Sheet
            self.StartColumn = oth.StartColumn
            self.StartRow = oth.StartRow
            self.EndColumn = oth.EndColumn
            self.EndRow = oth.EndRow
            return

        kargs = {
            "Sheet": Sheet,
            "StartColumn": StartColumn,
            "StartRow": StartRow,
            "EndColumn": EndColumn,
            "EndRow": EndRow,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._sheet = kwargs["Sheet"]
        self._start_column = kwargs["StartColumn"]
        self._start_row = kwargs["StartRow"]
        self._end_column = kwargs["EndColumn"]
        self._end_row = kwargs["EndRow"]


    @property
    def Sheet(self) -> int:
        """
        is the index of the sheet that contains the cell range.
        """
        return self._sheet
    
    @Sheet.setter
    def Sheet(self, value: int) -> None:
        self._sheet = value

    @property
    def StartColumn(self) -> int:
        """
        is the index of the column of the left edge of the range.
        """
        return self._start_column
    
    @StartColumn.setter
    def StartColumn(self, value: int) -> None:
        self._start_column = value

    @property
    def StartRow(self) -> int:
        """
        is the index of the row of the top edge of the range.
        """
        return self._start_row
    
    @StartRow.setter
    def StartRow(self, value: int) -> None:
        self._start_row = value

    @property
    def EndColumn(self) -> int:
        """
        is the index of the column of the right edge of the range.
        """
        return self._end_column
    
    @EndColumn.setter
    def EndColumn(self, value: int) -> None:
        self._end_column = value

    @property
    def EndRow(self) -> int:
        """
        is the index of the row of the bottom edge of the range.
        """
        return self._end_row
    
    @EndRow.setter
    def EndRow(self, value: int) -> None:
        self._end_row = value


__all__ = ['CellRangeAddress']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb


class BooleanComparisonMode(object):
    """
    Const Class

    specifies different mode how boolean comparison predicates are to be generated by a SingleSelectQueryComposer.

    See Also:
        `API BooleanComparisonMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1BooleanComparisonMode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.BooleanComparisonMode'
    __ooo_type_name__: str = 'const'

    EQUAL_INTEGER = 0
    """
    denotes the default comparison
    
    Most databases support comparing boolean expressions or column values directly with integer values: column = 0 respectively column = 1.
    """
    IS_LITERAL = 1
    """
    requires to use IS boolean_literal for boolean comparison.
    
    That is, the generated comparison predicates will be column IS TRUE resp. column IS FALSE.
    """
    EQUAL_LITERAL = 2
    """
    requires to use = boolean_literal for boolean comparison.
    
    That is, the generated comparison predicates will be column = TRUE resp. column = FALSE.
    """
    ACCESS_COMPAT = 3
    """
    requires to use an Microsoft Access compatible syntax for boolean comparison.
    """

__all__ = ['BooleanComparisonMode']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..util.color import Color as Color_68e908c5

class UnoControlFixedLineModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a UnoControlFixedLine.

    See Also:
        `API UnoControlFixedLineModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedLineModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlFixedLineModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
        ...

    @abstractproperty
    def FontDescriptor(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font attributes of the text in the control.
        """
        ...

    @abstractproperty
    def FontEmphasisMark(self) -> int:
        """
        specifies the com.sun.star.text.FontEmphasis value of the text in the control.
        """
        ...

    @abstractproperty
    def FontRelief(self) -> int:
        """
        specifies the com.sun.star.text.FontRelief value of the text in the control.
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def Label(self) -> str:
        """
        specifies the label of the control.
        """
        ...

    @abstractproperty
    def Orientation(self) -> int:
        """
        specifies the orientation of the control.
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        specifies that the control will be printed with the document.
        """
        ...

    @abstractproperty
    def TextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color (RGB) of the control.
        """
        ...

    @abstractproperty
    def TextLineColor(self) -> 'Color_68e908c5':
        """
        specifies the text line color (RGB) of the control.
        """
        ...



__all__ = ['UnoControlFixedLineModel']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from .x_data_transfer_provider_access import XDataTransferProviderAccess as XDataTransferProviderAccess_78691108
from .x_extended_toolkit import XExtendedToolkit as XExtendedToolkit_d4c90cc3
from .x_message_box_factory import XMessageBoxFactory as XMessageBoxFactory_edaf0d72
from .x_reschedule import XReschedule as XReschedule_993e0ab0
from .x_system_child_factory import XSystemChildFactory as XSystemChildFactory_fd200ded
from .x_toolkit import XToolkit as XToolkit_7adf0992

class XToolkit2(XDataTransferProviderAccess_78691108, XExtendedToolkit_d4c90cc3, XMessageBoxFactory_edaf0d72, XReschedule_993e0ab0, XSystemChildFactory_fd200ded, XToolkit_7adf0992):
    """
    Provides a unified interface for the new-style service Toolkit to implement.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XToolkit2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkit2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XToolkit2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XToolkit2'


__all__ = ['XToolkit2']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer.dnd
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class DNDConstants(metaclass=UnoConstMeta, type_name="com.sun.star.datatransfer.dnd.DNDConstants", name_space="com.sun.star.datatransfer.dnd"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.datatransfer.dnd.DNDConstants``"""
        pass

    class DNDConstantsEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.datatransfer.dnd.DNDConstants", name_space="com.sun.star.datatransfer.dnd"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.datatransfer.dnd.DNDConstants`` as Enum values"""
        pass

else:
    from ....lo.datatransfer.dnd.dnd_constants import DNDConstants as DNDConstants

    class DNDConstantsEnum(IntEnum):
        """
        Enum of Const Class DNDConstants

        These values represent the type of action or actions to be performed by a Drag and Drop operation.
        """
        ACTION_NONE = DNDConstants.ACTION_NONE
        """
        No action.
        """
        ACTION_COPY = DNDConstants.ACTION_COPY
        """
        Action copy.
        """
        ACTION_MOVE = DNDConstants.ACTION_MOVE
        """
        Action move.
        """
        ACTION_COPY_OR_MOVE = DNDConstants.ACTION_COPY_OR_MOVE
        """
        Action copy or move.
        """
        ACTION_LINK = DNDConstants.ACTION_LINK
        """
        Action link.
        """
        ACTION_REFERENCE = DNDConstants.ACTION_REFERENCE
        """
        Action reference.
        """
        ACTION_DEFAULT = DNDConstants.ACTION_DEFAULT
        """
        Action default.
        """

__all__ = ['DNDConstants', 'DNDConstantsEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TemplateDisplayFormat(metaclass=UnoConstMeta, type_name="com.sun.star.text.TemplateDisplayFormat", name_space="com.sun.star.text"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.text.TemplateDisplayFormat``"""
        pass

    class TemplateDisplayFormatEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.text.TemplateDisplayFormat", name_space="com.sun.star.text"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.text.TemplateDisplayFormat`` as Enum values"""
        pass

else:
    from ...lo.text.template_display_format import TemplateDisplayFormat as TemplateDisplayFormat

    class TemplateDisplayFormatEnum(IntEnum):
        """
        Enum of Const Class TemplateDisplayFormat

        These constants are used to specify which information about a template is displayed in a field.
        """
        FULL = TemplateDisplayFormat.FULL
        PATH = TemplateDisplayFormat.PATH
        NAME = TemplateDisplayFormat.NAME
        """
        Only the file name, without file extension, of the template file will be displayed.
        """
        NAME_AND_EXT = TemplateDisplayFormat.NAME_AND_EXT
        """
        The file name and the file extension of the template file will be displayed.
        """
        AREA = TemplateDisplayFormat.AREA
        """
        The name of the template area is displayed.
        """
        TITLE = TemplateDisplayFormat.TITLE
        """
        The title of the template file is displayed.
        """

__all__ = ['TemplateDisplayFormat', 'TemplateDisplayFormatEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form
# Libre Office Version: 7.4
from enum import Enum


class FormButtonType(Enum):
    """
    Enum Class

    

    See Also:
        `API FormButtonType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form.html#abd774094fc2fbbdf91448f8a60c1798a>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.FormButtonType'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.form.FormButtonType'

    PUSH = 'PUSH'
    """
    requires the button to act like a common push button, means no special action is triggered.
    """
    RESET = 'RESET'
    """
    When the button is clicked, it performs a reset on its containing form.
    """
    SUBMIT = 'SUBMIT'
    """
    When the button is clicked, it performs a submit on its containing form.
    """
    URL = 'URL'
    """
    When the button is clicked, a URL set for the button is opened.
    
    Specifies to use \"application/x-www-form-urlencoded\" as submit encoding.
    
    Usually used if the FormSubmitMethod attribute has the value POST.
    """

__all__ = ['FormButtonType']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class EntryInitModes(metaclass=UnoConstMeta, type_name="com.sun.star.embed.EntryInitModes", name_space="com.sun.star.embed"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.embed.EntryInitModes``"""
        pass

    class EntryInitModesEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.embed.EntryInitModes", name_space="com.sun.star.embed"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.embed.EntryInitModes`` as Enum values"""
        pass

else:
    from ...lo.embed.entry_init_modes import EntryInitModes as EntryInitModes

    class EntryInitModesEnum(IntEnum):
        """
        Enum of Const Class EntryInitModes

        This constant set contains possible modes to initialize object persistence.
        """
        DEFAULT_INIT = EntryInitModes.DEFAULT_INIT
        """
        In case object persistence is created based on existing entry, the object should be initialized from this entry.
        
        Otherwise the object should be initialized as a new one.
        """
        TRUNCATE_INIT = EntryInitModes.TRUNCATE_INIT
        """
        The object should be initialized as a new empty one.
        """
        NO_INIT = EntryInitModes.NO_INIT
        """
        The object should be initialized as a new one only in case it still was not initialized.
        
        If the object initialized already do not reinitialize it.
        """
        MEDIA_DESCRIPTOR_INIT = EntryInitModes.MEDIA_DESCRIPTOR_INIT
        """
        The object should be initialized using additional arguments from provided com.sun.star.document.MediaDescriptor.
        """
        URL_LINK_INIT = EntryInitModes.URL_LINK_INIT
        """
        The object should be initialized as a link using URL provided in additional arguments.
        """

__all__ = ['EntryInitModes', 'EntryInitModesEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.vba
import typing
from abc import abstractmethod, ABC

class XVBAEventProcessor(ABC):
    """
    Executes VBA event handlers.

    See Also:
        `API XVBAEventProcessor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1vba_1_1XVBAEventProcessor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script.vba'
    __ooo_full_ns__: str = 'com.sun.star.script.vba.XVBAEventProcessor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.vba.XVBAEventProcessor'

    @abstractmethod
    def hasVbaEventHandler(self, nEventId: int, aArgs: 'typing.Tuple[object, ...]') -> bool:
        """
        Returns whether a VBA event handler exists.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def processVbaEvent(self, nEventId: int, aArgs: 'typing.Tuple[object, ...]') -> bool:
        """
        Executes a VBA event handler.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.util.VetoException: ``VetoException``
        """
        ...

__all__ = ['XVBAEventProcessor']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..lang.locale import Locale as Locale_70d308fa


class NativeNumberXmlAttributes(object):
    """
    Struct Class

    Attributes describing a native number mode for a specific locale, stored in XML file format.
    
    Used with XNativeNumberSupplier.convertToXmlAttributes() and XNativeNumberSupplier.convertFromXmlAttributes()
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API NativeNumberXmlAttributes <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1NativeNumberXmlAttributes.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.NativeNumberXmlAttributes'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.NativeNumberXmlAttributes'
    """Literal Constant ``com.sun.star.i18n.NativeNumberXmlAttributes``"""

    def __init__(self, Locale: typing.Optional[Locale_70d308fa] = UNO_NONE, Format: typing.Optional[str] = '', Style: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Locale (Locale, optional): Locale value.
            Format (str, optional): Format value.
            Style (str, optional): Style value.
        """
        super().__init__()

        if isinstance(Locale, NativeNumberXmlAttributes):
            oth: NativeNumberXmlAttributes = Locale
            self.Locale = oth.Locale
            self.Format = oth.Format
            self.Style = oth.Style
            return

        kargs = {
            "Locale": Locale,
            "Format": Format,
            "Style": Style,
        }
        if kargs["Locale"] is UNO_NONE:
            kargs["Locale"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._locale = kwargs["Locale"]
        self._format = kwargs["Format"]
        self._style = kwargs["Style"]


    @property
    def Locale(self) -> Locale_70d308fa:
        """
        The locale of the native number representation.
        """
        return self._locale
    
    @Locale.setter
    def Locale(self, value: Locale_70d308fa) -> None:
        self._locale = value

    @property
    def Format(self) -> str:
        """
        The number \"1\" expressed as a native number string.
        """
        return self._format
    
    @Format.setter
    def Format(self, value: str) -> None:
        self._format = value

    @property
    def Style(self) -> str:
        """
        The type of the number string, for example, \"short\" or \"medium\" or \"long\".
        """
        return self._style
    
    @Style.setter
    def Style(self, value: str) -> None:
        self._style = value


__all__ = ['NativeNumberXmlAttributes']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class RowChangeEvent(EventObject_a3d70b03):
    """
    Struct Class

    indicates the type of change action on the data source.

    See Also:
        `API RowChangeEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sdb_1_1RowChangeEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.RowChangeEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sdb.RowChangeEvent'
    """Literal Constant ``com.sun.star.sdb.RowChangeEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Action: typing.Optional[int] = 0, Rows: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Action (int, optional): Action value.
            Rows (int, optional): Rows value.
        """

        if isinstance(Source, RowChangeEvent):
            oth: RowChangeEvent = Source
            self.Source = oth.Source
            self.Action = oth.Action
            self.Rows = oth.Rows
            return

        kargs = {
            "Source": Source,
            "Action": Action,
            "Rows": Rows,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._action = kwargs["Action"]
        self._rows = kwargs["Rows"]
        inst_keys = ('Action', 'Rows')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Action(self) -> int:
        """
        indicates the type of change.
        """
        return self._action
    
    @Action.setter
    def Action(self, value: int) -> None:
        self._action = value

    @property
    def Rows(self) -> int:
        """
        indicates the number of rows affected by the change.
        """
        return self._rows
    
    @Rows.setter
    def Rows(self, value: int) -> None:
        self._rows = value


__all__ = ['RowChangeEvent']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class UnsupportedOpenModeException(Exception_85530a09):
    """
    Exception Class

    This exception is used to indicate that the requested OpenMode is not supported.
    
    For example, each OpenCommandArgument supplied as argument of the command \"open\" contains such an open mode.

    See Also:
        `API UnsupportedOpenModeException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedOpenModeException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.UnsupportedOpenModeException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.ucb.UnsupportedOpenModeException'
    __pyunostruct__: str = 'com.sun.star.ucb.UnsupportedOpenModeException'

    typeName: str = 'com.sun.star.ucb.UnsupportedOpenModeException'
    """Literal Constant ``com.sun.star.ucb.UnsupportedOpenModeException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Mode: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Mode (int, optional): Mode value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Mode": Mode,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._mode = kwargs["Mode"]
        inst_keys = ('Mode',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def Mode(self) -> int:
        """
        contains the OpenMode that is not supported.
        """
        return self._mode
    
    @Mode.setter
    def Mode(self, value: int) -> None:
        self._mode = value


__all__ = ['UnsupportedOpenModeException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ....dyn.sdb.application.copy_table_continuation import CopyTableContinuation as CopyTableContinuation
from ....dyn.sdb.application.copy_table_continuation import CopyTableContinuationEnum as CopyTableContinuationEnum
from ....dyn.sdb.application.copy_table_operation import CopyTableOperation as CopyTableOperation
from ....dyn.sdb.application.copy_table_operation import CopyTableOperationEnum as CopyTableOperationEnum
from ....dyn.sdb.application.copy_table_row_event import CopyTableRowEvent as CopyTableRowEvent
from ....dyn.sdb.application.copy_table_wizard import CopyTableWizard as CopyTableWizard
from ....dyn.sdb.application.database_object import DatabaseObject as DatabaseObject
from ....dyn.sdb.application.database_object import DatabaseObjectEnum as DatabaseObjectEnum
from ....dyn.sdb.application.database_object_container import DatabaseObjectContainer as DatabaseObjectContainer
from ....dyn.sdb.application.database_object_container import DatabaseObjectContainerEnum as DatabaseObjectContainerEnum
from ....dyn.sdb.application.default_view_controller import DefaultViewController as DefaultViewController
from ....dyn.sdb.application.named_database_object import NamedDatabaseObject as NamedDatabaseObject
from ....dyn.sdb.application.x_copy_table_listener import XCopyTableListener as XCopyTableListener
from ....dyn.sdb.application.x_copy_table_wizard import XCopyTableWizard as XCopyTableWizard
from ....dyn.sdb.application.x_database_document_ui import XDatabaseDocumentUI as XDatabaseDocumentUI
from ....dyn.sdb.application.x_table_ui_provider import XTableUIProvider as XTableUIProvider



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import typing
from abc import abstractmethod
from .x_locale_data4 import XLocaleData4 as XLocaleData4_a7ae0a9e
if typing.TYPE_CHECKING:
    from .locale_data_item2 import LocaleDataItem2 as LocaleDataItem2_cad20bd3
    from ..lang.locale import Locale as Locale_70d308fa

class XLocaleData5(XLocaleData4_a7ae0a9e):
    """
    Access locale specific data.
    
    Derived from com.sun.star.i18n.XLocaleData4 this provides an additional method to return an instance of com.sun.star.i18n.LocaleDataItem2
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API XLocaleData5 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XLocaleData5.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XLocaleData5'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XLocaleData5'

    @abstractmethod
    def getLocaleItem2(self, Locale: 'Locale_70d308fa') -> 'LocaleDataItem2_cad20bd3':
        """
        returns an instance of com.sun.star.i18n.LocaleDataItem2 for a Locale.
        """
        ...

__all__ = ['XLocaleData5']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .sql_error_event import SQLErrorEvent as SQLErrorEvent_ac5f0b3d

class XSQLErrorListener(XEventListener_c7230c4a):
    """
    the listener interface for receiving \"errorOccured\" events posted by any database object.

    See Also:
        `API XSQLErrorListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLErrorListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XSQLErrorListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XSQLErrorListener'

    @abstractmethod
    def errorOccured(self, aEvent: 'SQLErrorEvent_ac5f0b3d') -> None:
        """
        invoked when a database error occurs, just before a com.sun.star.sdbc.SQLException is thrown to the application.
        """
        ...

__all__ = ['XSQLErrorListener']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.vba
import typing
from abc import abstractmethod, abstractproperty, ABC
if typing.TYPE_CHECKING:
    from .xvba_script_listener import XVBAScriptListener as XVBAScriptListener_533e0ff0

class XVBACompatibility(ABC):
    """

    See Also:
        `API XVBACompatibility <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1vba_1_1XVBACompatibility.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script.vba'
    __ooo_full_ns__: str = 'com.sun.star.script.vba.XVBACompatibility'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.vba.XVBACompatibility'

    @abstractmethod
    def addVBAScriptListener(self, Listener: 'XVBAScriptListener_533e0ff0') -> None:
        """
        """
        ...
    @abstractmethod
    def broadcastVBAScriptEvent(self, Identifier: int, ModuleName: str) -> None:
        """
        """
        ...
    @abstractmethod
    def removeVBAScriptListener(self, Listener: 'XVBAScriptListener_533e0ff0') -> None:
        """
        """
        ...
    @abstractproperty
    def ProjectName(self) -> str:
        """
        """
        ...

    @abstractproperty
    def RunningVBAScripts(self) -> int:
        """
        """
        ...

    @abstractproperty
    def VBACompatibilityMode(self) -> bool:
        """
        """
        ...


__all__ = ['XVBACompatibility']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.input
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XNamespaceMapping(XInterface_8f010a43):
    """
    Interface to map XML namespace URI strings to ordinals (URI-id, short uid).

    See Also:
        `API XNamespaceMapping <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1input_1_1XNamespaceMapping.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.input'
    __ooo_full_ns__: str = 'com.sun.star.xml.input.XNamespaceMapping'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.input.XNamespaceMapping'

    @abstractmethod
    def getUidByUri(self, uri: str) -> int:
        """
        Creates a unique ordinal passing an XML namespace URI.
        """
        ...
    @abstractmethod
    def getUriByUid(self, uid: int) -> str:
        """
        Gets the corresponding XML namespace URI passing a uid (created using getUidByUri()).

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XNamespaceMapping']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_authorizable import XAuthorizable as XAuthorizable_c8dd0c5e
from .x_users_supplier import XUsersSupplier as XUsersSupplier_d6060cda

class Group(XPropertySet_bc180bfa, XAuthorizable_c8dd0c5e, XUsersSupplier_d6060cda):
    """
    Service Class

    represents a group of users, which has certain access rights for the objects of the database.

    See Also:
        `API Group <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1Group.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.Group'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Name(self) -> str:
        """
        is the name of the group.
        """
        ...



__all__ = ['Group']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class UnicodeType(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.UnicodeType", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.UnicodeType``"""
        pass

    class UnicodeTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.UnicodeType", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.UnicodeType`` as Enum values"""
        pass

else:
    from ...lo.i18n.unicode_type import UnicodeType as UnicodeType

    class UnicodeTypeEnum(IntEnum):
        """
        Enum of Const Class UnicodeType

        Constants to classify Unicode characters, returned by XCharacterClassification.getType()
        """
        UNASSIGNED = UnicodeType.UNASSIGNED
        UPPERCASE_LETTER = UnicodeType.UPPERCASE_LETTER
        LOWERCASE_LETTER = UnicodeType.LOWERCASE_LETTER
        TITLECASE_LETTER = UnicodeType.TITLECASE_LETTER
        MODIFIER_LETTER = UnicodeType.MODIFIER_LETTER
        OTHER_LETTER = UnicodeType.OTHER_LETTER
        NON_SPACING_MARK = UnicodeType.NON_SPACING_MARK
        ENCLOSING_MARK = UnicodeType.ENCLOSING_MARK
        COMBINING_SPACING_MARK = UnicodeType.COMBINING_SPACING_MARK
        DECIMAL_DIGIT_NUMBER = UnicodeType.DECIMAL_DIGIT_NUMBER
        LETTER_NUMBER = UnicodeType.LETTER_NUMBER
        OTHER_NUMBER = UnicodeType.OTHER_NUMBER
        SPACE_SEPARATOR = UnicodeType.SPACE_SEPARATOR
        LINE_SEPARATOR = UnicodeType.LINE_SEPARATOR
        PARAGRAPH_SEPARATOR = UnicodeType.PARAGRAPH_SEPARATOR
        CONTROL = UnicodeType.CONTROL
        FORMAT = UnicodeType.FORMAT
        PRIVATE_USE = UnicodeType.PRIVATE_USE
        SURROGATE = UnicodeType.SURROGATE
        DASH_PUNCTUATION = UnicodeType.DASH_PUNCTUATION
        INITIAL_PUNCTUATION = UnicodeType.INITIAL_PUNCTUATION
        FINAL_PUNCTUATION = UnicodeType.FINAL_PUNCTUATION
        CONNECTOR_PUNCTUATION = UnicodeType.CONNECTOR_PUNCTUATION
        OTHER_PUNCTUATION = UnicodeType.OTHER_PUNCTUATION
        MATH_SYMBOL = UnicodeType.MATH_SYMBOL
        CURRENCY_SYMBOL = UnicodeType.CURRENCY_SYMBOL
        MODIFIER_SYMBOL = UnicodeType.MODIFIER_SYMBOL
        OTHER_SYMBOL = UnicodeType.OTHER_SYMBOL
        START_PUNCTUATION = UnicodeType.START_PUNCTUATION
        END_PUNCTUATION = UnicodeType.END_PUNCTUATION
        GENERAL_TYPES_COUNT = UnicodeType.GENERAL_TYPES_COUNT

__all__ = ['UnicodeType', 'UnicodeTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.document
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class OwnLockOnDocumentRequest(Exception_85530a09):
    """
    Exception Class

    Is used for interaction handle to query user decision regarding locked document.
    
    **since**
    
        OOo 3.1

    See Also:
        `API OwnLockOnDocumentRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1document_1_1OwnLockOnDocumentRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.OwnLockOnDocumentRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.document.OwnLockOnDocumentRequest'
    __pyunostruct__: str = 'com.sun.star.document.OwnLockOnDocumentRequest'

    typeName: str = 'com.sun.star.document.OwnLockOnDocumentRequest'
    """Literal Constant ``com.sun.star.document.OwnLockOnDocumentRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, DocumentURL: typing.Optional[str] = '', TimeInfo: typing.Optional[str] = '', IsStoring: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            DocumentURL (str, optional): DocumentURL value.
            TimeInfo (str, optional): TimeInfo value.
            IsStoring (bool, optional): IsStoring value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "DocumentURL": DocumentURL,
            "TimeInfo": TimeInfo,
            "IsStoring": IsStoring,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._document_url = kwargs["DocumentURL"]
        self._time_info = kwargs["TimeInfo"]
        self._is_storing = kwargs["IsStoring"]
        inst_keys = ('DocumentURL', 'TimeInfo', 'IsStoring')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def DocumentURL(self) -> str:
        """
        The URL of the locked document.
        """
        return self._document_url
    
    @DocumentURL.setter
    def DocumentURL(self, value: str) -> None:
        self._document_url = value

    @property
    def TimeInfo(self) -> str:
        """
        The time from which the document is locked.
        """
        return self._time_info
    
    @TimeInfo.setter
    def TimeInfo(self, value: str) -> None:
        self._time_info = value

    @property
    def IsStoring(self) -> bool:
        """
        Whether the request is related to storing process.
        """
        return self._is_storing
    
    @IsStoring.setter
    def IsStoring(self, value: bool) -> None:
        self._is_storing = value


__all__ = ['OwnLockOnDocumentRequest']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
import typing
from abc import abstractmethod
from .x_dictionary import XDictionary as XDictionary_fea70de3
if typing.TYPE_CHECKING:
    from .x_dictionary_entry import XDictionaryEntry as XDictionaryEntry_49ef0ff5

class XSearchableDictionary(XDictionary_fea70de3):
    """
    This interfaces allows to retrieve suggestions for spell checking from a dictionary.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API XSearchableDictionary <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XSearchableDictionary.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XSearchableDictionary'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XSearchableDictionary'

    @abstractmethod
    def searchSimilarEntries(self, aWord: str) -> 'typing.Tuple[XDictionaryEntry_49ef0ff5, ...]':
        """
        search for similar entries in the dictionary.
        
        **since**
        
            OOo 3.0.1
        """
        ...

__all__ = ['XSearchableDictionary']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class DataPilotTablePositionType(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.DataPilotTablePositionType", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.DataPilotTablePositionType``"""
        pass

    class DataPilotTablePositionTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.DataPilotTablePositionType", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.DataPilotTablePositionType`` as Enum values"""
        pass

else:
    from ...lo.sheet.data_pilot_table_position_type import DataPilotTablePositionType as DataPilotTablePositionType

    class DataPilotTablePositionTypeEnum(IntEnum):
        """
        Enum of Const Class DataPilotTablePositionType

        specifies in which sub-area a cell is positioned within a DataPilot table.
        
        **since**
        
            OOo 3.0
        """
        NOT_IN_TABLE = DataPilotTablePositionType.NOT_IN_TABLE
        """
        indicates that the specified cell is not in the DataPilot table.
        """
        RESULT = DataPilotTablePositionType.RESULT
        """
        indicates that the specified cell is within the result area.
        """
        ROW_HEADER = DataPilotTablePositionType.ROW_HEADER
        """
        indicates that the specified cell is within the row header area.
        """
        COLUMN_HEADER = DataPilotTablePositionType.COLUMN_HEADER
        """
        indicates that the specified cell is within the column header area.
        """
        OTHER = DataPilotTablePositionType.OTHER
        """
        indicates that the specified cell is within the table but in areas other than the result or header areas.
        """

__all__ = ['DataPilotTablePositionType', 'DataPilotTablePositionTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_action_listener import XActionListener as XActionListener_c7560c50

class XFixedHyperlink(XInterface_8f010a43):
    """
    gives access to the text and formatting of a fixed hyperlink field.

    See Also:
        `API XFixedHyperlink <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XFixedHyperlink.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XFixedHyperlink'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XFixedHyperlink'

    @abstractmethod
    def addActionListener(self, l: 'XActionListener_c7560c50') -> None:
        """
        registers an event handler for click action event.
        """
        ...
    @abstractmethod
    def getAlignment(self) -> int:
        """
        returns the alignment of the text in the control.
        """
        ...
    @abstractmethod
    def getText(self) -> str:
        """
        returns the text of the control.
        """
        ...
    @abstractmethod
    def getURL(self) -> str:
        """
        returns the url of the control.
        """
        ...
    @abstractmethod
    def removeActionListener(self, l: 'XActionListener_c7560c50') -> None:
        """
        unregisters an event handler for click action event.
        """
        ...
    @abstractmethod
    def setAlignment(self, nAlign: int) -> None:
        """
        sets the alignment of the text in the control.
        """
        ...
    @abstractmethod
    def setText(self, Text: str) -> None:
        """
        sets the text of the control.
        """
        ...
    @abstractmethod
    def setURL(self, URL: str) -> None:
        """
        sets the url of the control.
        """
        ...

__all__ = ['XFixedHyperlink']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.mozilla
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .menu_multiple_change import MenuMultipleChange as MenuMultipleChange_2cc20f27
    from .menu_single_change import MenuSingleChange as MenuSingleChange_dad0e3d

class XMenuProxyListener(XInterface_8f010a43):
    """
    Listens for changes in menu items.

    See Also:
        `API XMenuProxyListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1mozilla_1_1XMenuProxyListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.mozilla'
    __ooo_full_ns__: str = 'com.sun.star.mozilla.XMenuProxyListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.mozilla.XMenuProxyListener'

    @abstractmethod
    def menuChangedMultiple(self, MenuMultipleChanges: 'typing.Tuple[MenuMultipleChange_2cc20f27, ...]') -> None:
        """
        is called, if the content or graphical representation/state of the menu changes completely, for one or more menu items
        """
        ...
    @abstractmethod
    def menuChangedSingle(self, MenuSingleChanges: 'typing.Tuple[MenuSingleChange_dad0e3d, ...]') -> None:
        """
        is called, if the content or graphical representation/state of the menu changes, by one property for one or more menu items
        """
        ...
    @abstractmethod
    def menuItemDeleted(self, ID: int) -> None:
        """
        is called, if one menu item designated by the ID, is deleted.
        """
        ...

__all__ = ['XMenuProxyListener']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
from ..beans.property_state import PropertyState as PropertyState_c97b0c77
import typing
from .property_value_state import PropertyValueState as PropertyValueState_f1050da5


class PropertyValueInfo(PropertyValue_c9610c73):
    """
    Struct Class

    contains value and state of a com.sun.star.beans.Property.

    See Also:
        `API PropertyValueInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1PropertyValueInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.PropertyValueInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.PropertyValueInfo'
    """Literal Constant ``com.sun.star.ucb.PropertyValueInfo``"""

    def __init__(self, Name: typing.Optional[str] = '', Handle: typing.Optional[int] = 0, Value: typing.Optional[object] = None, State: typing.Optional[PropertyState_c97b0c77] = PropertyState_c97b0c77.DIRECT_VALUE, ValueState: typing.Optional[PropertyValueState_f1050da5] = PropertyValueState_f1050da5.UNPROCESSED) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Handle (int, optional): Handle value.
            Value (object, optional): Value value.
            State (PropertyState, optional): State value.
            ValueState (PropertyValueState, optional): ValueState value.
        """

        if isinstance(Name, PropertyValueInfo):
            oth: PropertyValueInfo = Name
            self.Name = oth.Name
            self.Handle = oth.Handle
            self.Value = oth.Value
            self.State = oth.State
            self.ValueState = oth.ValueState
            return

        kargs = {
            "Name": Name,
            "Handle": Handle,
            "Value": Value,
            "State": State,
            "ValueState": ValueState,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._value_state = kwargs["ValueState"]
        inst_keys = ('ValueState',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def ValueState(self) -> PropertyValueState_f1050da5:
        """
        the state of the property value.
        """
        return self._value_state
    
    @ValueState.setter
    def ValueState(self, value: PropertyValueState_f1050da5) -> None:
        self._value_state = value


__all__ = ['PropertyValueInfo']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TimeDisplayFormat(metaclass=UnoConstMeta, type_name="com.sun.star.text.TimeDisplayFormat", name_space="com.sun.star.text"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.text.TimeDisplayFormat``"""
        pass

    class TimeDisplayFormatEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.text.TimeDisplayFormat", name_space="com.sun.star.text"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.text.TimeDisplayFormat`` as Enum values"""
        pass

else:
    from ...lo.text.time_display_format import TimeDisplayFormat as TimeDisplayFormat

    class TimeDisplayFormatEnum(IntEnum):
        """
        Enum of Const Class TimeDisplayFormat

        These constants define how a time field is formatted before it is displayed.
        
        The format may also depend on the system or document locale.
        
        .. deprecated::
        
            Class is deprecated.
        """
        STANDARD = TimeDisplayFormat.STANDARD
        """
        the system standard
        """
        HHMM = TimeDisplayFormat.HHMM
        """
        13:49
        """
        HHMMSS = TimeDisplayFormat.HHMMSS
        """
        13:49:20
        """
        HHMMSS00 = TimeDisplayFormat.HHMMSS00
        """
        13:49:20.30
        """
        HHMMAMPM = TimeDisplayFormat.HHMMAMPM
        """
        01:49
        """
        HHMMSSAMPM = TimeDisplayFormat.HHMMSSAMPM
        """
        01:49:20
        """
        HHMMSS00AMPM = TimeDisplayFormat.HHMMSS00AMPM
        """
        01:49:20.30
        """

__all__ = ['TimeDisplayFormat', 'TimeDisplayFormatEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from enum import Enum


class AxisOrientation(Enum):
    """
    Enum Class

    ENUM AxisOrientation

    See Also:
        `API AxisOrientation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart2.html#aceb583a87538899d77ffbe62d2176a43>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.AxisOrientation'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.chart2.AxisOrientation'

    MATHEMATICAL = 'MATHEMATICAL'
    """
    means equal to the primary writing direction
    """
    REVERSE = 'REVERSE'
    """
    means the opposite of the primary writing direction
    """

__all__ = ['AxisOrientation']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.configuration.backend
# Libre Office Version: 7.4
import typing
from ...lang.wrapped_target_exception import WrappedTargetException as WrappedTargetException_38ae0f93
from ...uno.x_interface import XInterface as XInterface_8f010a43

class BackendAccessException(WrappedTargetException_38ae0f93):
    """
    Exception Class

    Generic exception thrown when physical access to an underlying backend fails.
    
    Wraps an exception that originates in the underlying access layer.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API BackendAccessException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1configuration_1_1backend_1_1BackendAccessException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.BackendAccessException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.BackendAccessException'
    __pyunostruct__: str = 'com.sun.star.configuration.backend.BackendAccessException'

    typeName: str = 'com.sun.star.configuration.backend.BackendAccessException'
    """Literal Constant ``com.sun.star.configuration.backend.BackendAccessException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, TargetException: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            TargetException (object, optional): TargetException value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "TargetException": TargetException,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        super()._init(**kwargs)


__all__ = ['BackendAccessException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from abc import abstractmethod
from .x_updatable import XUpdatable as XUpdatable_9a420ab0

class XUpdatable2(XUpdatable_9a420ab0):
    """
    This interface extends XUpdatable in order to provide more fine-tuned update modes.
    
    When performing a soft update, the implementor may decide not to update in certain cases, such as when the controller is locked. When performing a hard update, on the other hand, the implementor should perform update more aggressively even when the controller is locked.

    See Also:
        `API XUpdatable2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XUpdatable2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XUpdatable2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XUpdatable2'

    @abstractmethod
    def updateHard(self) -> None:
        """
        Perform update, even when the controller is locked.
        """
        ...
    @abstractmethod
    def updateSoft(self) -> None:
        """
        Perform update, but update may not always be performed especially when the controller is locked.
        """
        ...

__all__ = ['XUpdatable2']

